@@ -4,7 +4,7 @@
 
 ;; Author: Jorgen Schaefer <contact@jorgenschaefer.de>
 ;; URL: http://github.com/jorgenschaefer/pyvenv
-;; Version: 1.17
+;; Version: 1.20
 ;; Keywords: Python, Virtualenv, Tools
 
 ;; This program is free software; you can redistribute it and/or
@@ -287,16 +287,15 @@ This is usually the base name of `pyvenv-virtual-env'.")
 
 ;;;###autoload
 (defun pyvenv-workon (name)
-  "Activate a virtual environment from $WORKON_HOME."
+  "Activate a virtual environment from $WORKON_HOME.
+
+If the virtual environment NAME is already active, this function
+does not try to reactivate the environment."
   (interactive
    (list
     (completing-read "Work on: " (pyvenv-virtualenv-list)
                      nil t nil 'pyvenv-workon-history nil nil)))
-  (when (not (or (equal name "")
-                 ;; Some completion frameworks can return nil for the
-                 ;; default, see
-                 ;; https://github.com/jorgenschaefer/elpy/issues/144
-                 (equal name nil)))
+  (unless (member name (list "" nil pyvenv-virtual-env-name))
     (pyvenv-activate (format "%s/%s"
                              (pyvenv-workon-home)
                              name))))
